@@ -1,5 +1,3 @@
-use std::time::Duration;
-
 use nacos_naming_client:: {
     NamingClient, HttpNamingRemote, NamingConfig, constants, ServerConfig,
     ServiceChangeListener, model::ServiceInfo, model::Instance,
@@ -107,21 +105,6 @@ pub async fn gen_channel(service_name: &str) -> Channel {
         log::error!("failed to subscribe service change: {}", error);
         return channel;
     }
-
-    let service_name = service_name.to_string();
-    tokio::spawn(async move {
-        loop {
-            let resp = nacos_client.select_instances(
-                service_name.as_str(), nacos_client.get_group(), vec![nacos_client.get_cluster()], true
-            ).await;
-        
-            if let Err(error) = resp {
-                log::error!("failed to get instance of service: {}, cause: {}", service_name, error);
-            }
-            tokio::time::sleep(Duration::from_secs(10)).await
-        }
-    });
-
     channel
 }
 
